@@ -55,31 +55,28 @@ class BooleanOperator(Enum):
     OR = auto()
 
 
-class TimePeriodOperator(Enum):
-    FROM = auto()
-    TO = auto()
-    INTERVAL = auto()
+class PeriodOperator(Enum):
+    PREV = auto()
+    CURR = auto()
+    NEXT = auto()
 
 
 class TimeOperator(Enum):
-    PERIOD = auto()
-    PREV_PERIOD = auto()
-    FROM_PREV_PERIOD = auto()
-    TO_PREV_PERIOD = auto()
-    NEXT_PERIOD = auto()
-    FROM_NEXT_PERIOD = auto()
-    TO_NEXT_PERIOD = auto()
-    FROM_PERIOD = auto()
-    TO_PERIOD = auto()
+    RANGE = auto()
+    FROM = auto()
+    TO = auto()
 
 
 @dataclass
 class Condition:
     field: Field
-    operator: Union[SQLOperator, TimeOperator, TimePeriodOperator, str]
+    operator: Union[SQLOperator, TimeOperator, str]
     value: Optional[List[Union[float, str]]] = None
     type: Optional[str] = None
-    window: Optional[str] = None
+    until: Optional[List[Union[float, str]]] = None
+    steps: Optional[str] = None
+    interval: Optional[str] = None
+    direction: Optional[PeriodOperator] = None
 
     def __repr__(self):
         vars = []
